@@ -693,9 +693,12 @@ void BookWindow::EndSlot()
         case EndWindow::Load:
             Init();
             break;
-        case EndWindow::Restart:
-            Load(GetBookSaveFilename(m_Book->Number));
-            ShowSection(m_Section->Number);
+        case EndWindow::Restart:{
+                Load(GetBookSaveFilename(m_Book->Number));
+                QScriptValue objectValue = m_Engine.newQObject(m_Player);
+                m_Engine.globalObject().setProperty("Player", objectValue);
+                ShowSection(m_Section->Number);
+            }
             break;
         case EndWindow::MainMenu:
             close();
@@ -862,7 +865,7 @@ bool BookWindow::Load(QString filename)
             Item* i = new Item(var.value<Item>());
             // For compatibility with previously saved positions, check if the item has
             // the CanBeEquipped property
-            if ((i->GetIsArmor() || i->GetIsWeapon()) && i->GetProperty("CanBeEquipped").isEmpty())
+            if ((i->GetIsArmor() || i->GetIsWeapon()) && !i->HasProperty("CanBeEquipped"))
                 i->SetCanBeEquipped(true);
             m_Player->Items.append(i);
         }else{
@@ -871,7 +874,7 @@ bool BookWindow::Load(QString filename)
                 Weapon* w = new Weapon(var.value<Weapon>());                
                 // For compatibility with previously saved positions, check if the weapon has
                 // the CanBeEquipped property
-                if (w->GetProperty("CanBeEquipped").isEmpty())
+                if (!w->HasProperty("CanBeEquipped"))
                     w->SetCanBeEquipped(true);
                 m_Player->Items.append(w);
             }
