@@ -16,6 +16,7 @@ public:
     QHash<QString, QString> Properties;
 
 public slots:
+    bool HasProperty(QString name) { return Properties.contains(name); }
     QString GetProperty(QString name);
     void SetProperty(QString name, QString value);
     bool GetBoolProperty(QString name) { return GetProperty(name).toInt() == 1;}
@@ -76,7 +77,7 @@ public slots:
     bool GetIsWeapon() { return GetBoolProperty("IsWeapon"); }
     void SetIsWeapon(bool value) { SetBoolProperty("IsWeapon", value); }
 
-    bool GetCanBeEquipped() { return GetBoolProperty("CanBeEquipped"); }
+    bool GetCanBeEquipped();
     void SetCanBeEquipped(bool value);
 
     bool GetIsArmor() { return GetBoolProperty("IsArmor"); }
