@@ -2,6 +2,7 @@
 #define MAINWINDOW_H
 
 #include <QMainWindow>
+#include "core/books.h"
 
 namespace Ui {
     class MainWindow;
@@ -15,9 +16,16 @@ public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
+    void showMaximized();
+    void show();
+
 private:
     Ui::MainWindow *ui;
 
+    Books* m_Books;
+    bool IsConnected();
+    void CheckUpdate();
+
 protected:
     void closeEvent(QCloseEvent *event);
 
